@@ -29,7 +29,11 @@ PLATFORM2ARCH = {
     'Darwin': 'mac64',
     'Windows': 'win32',
 }
+_ARCH = PLATFORM2ARCH[platform.system()]
 DEFAULT_EXE = 'google-chrome'
+if _ARCH == 'mac64':
+    DEFAULT_EXE = '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome'
+
 
 try:
     cache_dir = os.environ['REQUESTS_CACHE_DIR']
@@ -86,10 +90,6 @@ def my_chrome_version(exe=DEFAULT_EXE) -> Version:
     return Version.from_re_match(r'.*?([\d.]+).*?', out)
 
 
-def my_arch():
-    return PLATFORM2ARCH[platform.system()]
-
-
 def driver_version(chromedriver: Path):
     out = subprocess.check_output([chromedriver, '--version'], encoding='utf-8')
     return Version.from_re_match(r'ChromeDriver ([\d.]+).*?', out)
@@ -147,8 +147,7 @@ def download_latest(target_dir: Path, force=False) -> [Version, Path]:
     if not target_dir.is_dir():
         raise ChromedriverDownloadError(f'not a directory: {target_dir}')
 
-    arch = my_arch()
-    repo = ChromedriverRepo(arch)
+    repo = ChromedriverRepo(_ARCH)
     chromedriver_version = repo.latest_version(my_chrome_version().major)
 
     target = target_dir / f'chromedriver-{chromedriver_version}'
