@@ -6,12 +6,12 @@ import click
 import structlog
 from click import ClickException
 
-import hukudo.chromedriver
-import hukudo.filesystem
+import hukudo
 from hukudo.exc import HukudoException
 from hukudo.log import LOG_LEVELS, configure_structlog_dev
 from .gitlab.cli import gitlab
 from .grafana.cli import grafana
+from .pypi.cli import pypi
 
 
 @click.group()
@@ -38,6 +38,8 @@ def root(log_level):
 root.add_command(grafana)
 # noinspection PyTypeChecker
 root.add_command(gitlab)
+# noinspection PyTypeChecker
+root.add_command(pypi)
 
 
 @root.command()
@@ -65,6 +67,8 @@ def download(skip_symlink, force, target_dir):
 
     Results in `/tmp/chromedriver` pointing to `/tmp/chromedriver-101.0.4951.41`.
     """
+    import hukudo.chromedriver
+
     try:
         hukudo.chromedriver.download_and_symlink(target_dir, force=force, skip_symlink=skip_symlink)
     except HukudoException as e:
@@ -76,6 +80,8 @@ def download(skip_symlink, force, target_dir):
 @click.argument('directory', type=click.Path(path_type=Path))
 def keepn_(num: int, directory: Path):
     """Keep NUM files in DIRECTORY and delete the rest."""
+    import hukudo.filesystem
+
     hukudo.filesystem.keepn(directory=directory, n_keep=num)
 
 
