@@ -30,4 +30,4 @@ class Dashboard(JSONThing):
 
     def export(self, path):
         path = Path(path)
-        path.write_text(json.dumps(self.raw))
+        path.write_text(json.dumps(self.raw, sort_keys=True, indent=2))
